@@ -40,12 +40,13 @@ def stock_RT_HH_MA_pre(table_name='stock_day_adj_fillna', N=250): # ok
     trade_date = rq_util_get_last_tradedate()
     #print(trade_date)
     start_date = rq_util_get_pre_trade_date(trade_date,N)
-    #df = read_sql_from_pg(start_date=start_date, data=\
-    #        "trade_date,open,high,low,close,pre_close,vol,amount,\
-    #        adj_factor,code,pct_chg,avg",table_name=table_name, client=client_rrshare)
+    df = read_sql_from_pg(start_date=start_date, data=\
+            "trade_date,open,high,low,close,pre_close,vol,amount,\
+            adj_factor,code,pct_chg,avg",table_name=table_name, client=client_rrshare)
     delist_code = fetch_delist_stock(trade_date) 
-    df = pd.read_pickle("~/.rrsdk/data/stock_day_20210502.pkl")
-    print(df.tail())
+    #df = pd.read_pickle("~/.rrsdk/data/stock_day_20210502.pkl")
+    #print(df.tail())
+    df.to_pickle("~/.rrsdk/data/stock_day_adj_250.pkl")
     df =df[~df['code'].isin(delist_code)]
     
     df_i = df.set_index(['trade_date','code'])
@@ -107,7 +108,7 @@ def stock_RS_OH_MA_last(table_name='stock_day_adj_fillna', N=250): # ok
         df[i] = pd.to_numeric(df[i], errors='coerce')
     """
     delist_code = fetch_delist_stock(trade_date) 
-    df = pd.read_pickle('~/.rrsdk/data/stock_day_20210502.pkl')
+    df = pd.read_pickle('~/.rrsdk/data/stock_day_adj_250.pkl')
     df =df[~df['code'].isin(delist_code)]
     df_i = df.set_index(['trade_date','code'])
     df_i.drop_duplicates(keep='last',inplace=True)
