@@ -25,6 +25,7 @@
 If your goal in creating a Streamlit Component is solely to display HTML code or render a chart from a Python visualization library, 
 Streamlit provides two methods that greatly simplify the process: components.html() and components.iframe().
 """
+
 from enum import unique
 import time
 import datetime
@@ -35,13 +36,13 @@ from streamlit.components.v1 import components
 
 from rrshare.rqUtil import (client_pgsql,read_data_from_pg,read_sql_from_pg)
 from rrshare.rqUtil import  (rq_util_date_today,rq_util_get_pre_trade_date,rq_util_get_last_tradedate, trade_date_sse)
-from rrshare.rqUtil import is_before_tradetime_secs_cn, is_trade_time_secs_cn, rq_util_if_trade
+from rrshare.rqUtil import is_before_tradetime_secs_cn, is_trade_time_secs_cn, rq_util_if_trade, is_tradeday_and_market_opened
 
 
 conn = client_pgsql('rrfactor')
 lastTD = rq_util_get_last_tradedate()
 today_ = rq_util_date_today().strftime('%Y-%m-%d') 
-trade_date = today_  if today_ in trade_date_sse else rq_util_get_last_tradedate()
+trade_date = today_  if is_tradeday_and_market_opened() else rq_util_get_last_tradedate()
 #now_ = datetime.datetime.now()
 
 current = datetime.datetime.now()
